| Title: | Search and Get Data from the I14Y Interoperability Platform of Switzerland |
|---|---|
| Description: | Search and download Swiss data and metadata from the I14Y interoperability platform of Switzerland using its public APIs <https://www.i14y.admin.ch/api/index.html>. |
| Authors: | Felix Luginbuhl [aut, cre, cph] (ORCID: <https://orcid.org/0009-0008-6625-2899>), Felix Lorenz [ctb] |
| Maintainer: | Felix Luginbuhl <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.2.0 |
| Built: | 2026-07-11 10:58:14 UTC |
| Source: | https://github.com/lgnbhl/I14Y |
Calls the I14Y public API endpoint
/concepts/{conceptId}/codelist-entries/search/exports/{dataFormat}.
i14y_export_codelist_search( id = NULL, query = NULL, language = "de", filters = NULL, format = "csv", withAnnotations = FALSE )i14y_export_codelist_search( id = NULL, query = NULL, language = "de", filters = NULL, format = "csv", withAnnotations = FALSE )
id |
string. The UUID of the codelist concept. |
query |
string. The search query. If 'NULL', all entries are returned (subject to 'filters', 'page' and 'pageSize'). |
language |
string. The language of the response data ("de", "fr", "en", "it", "rm"). Default "de". |
filters |
character vector. Optional filter expressions, passed through to the API as the 'filters' array parameter. |
format |
string. The export format ("csv" or "json"). |
withAnnotations |
logical. If 'TRUE', annotations are included. |
A tibble for "csv", a list for "json". 'NULL' when offline.
Calls the I14Y public API endpoint /catalogs/{catalogId}.
i14y_get_catalog(id = NULL)i14y_get_catalog(id = NULL)
id |
string. The catalog identifier. |
A list of catalog metadata. 'NULL' when offline.
Calls the I14Y public API endpoint
/catalogs/{catalogId}/dcat/exports/{dataFormat}.
i14y_get_catalog_dcat(id = NULL, format = "RDF")i14y_get_catalog_dcat(id = NULL, format = "RDF")
id |
string. The catalog identifier. |
format |
string. One of "RDF" (default), "TTL". |
A character string with the raw RDF/TTL document. 'NULL' when offline.
Calls the I14Y public API endpoint
/catalogs/{catalogId}/records/{recordId}.
i14y_get_catalog_record(id = NULL, recordId = NULL)i14y_get_catalog_record(id = NULL, recordId = NULL)
id |
string. The catalog identifier. |
recordId |
string. The record identifier. |
A list with the record metadata. 'NULL' when offline.
Calls the I14Y public API endpoint /catalogs/{catalogId}/records.
i14y_get_catalog_records(id = NULL)i14y_get_catalog_records(id = NULL)
id |
string. The catalog identifier. |
A tibble of catalog records. 'NULL' when offline.
Calls the I14Y public API endpoint
/concepts/{conceptId}/codelist-entries/exports/{dataFormat}.
i14y_get_codelist(id = NULL, format = "csv", withAnnotations = FALSE)i14y_get_codelist(id = NULL, format = "csv", withAnnotations = FALSE)
id |
string. The Id of the response data. |
format |
string. The format of the export ("csv" or "json"). |
withAnnotations |
logical. If 'TRUE', annotations are included in the export. Default 'FALSE'. |
A tibble for 'format = "csv"'. For 'format = "json"', a list when 'withAnnotations = TRUE' (preserves the nested structure) or a tibble otherwise. 'NULL' when offline.
i14y_get_codelist( id = "08d94604-e058-62a2-aa25-53f84b974201" # for DV_NOGA_DIVISION )i14y_get_codelist( id = "08d94604-e058-62a2-aa25-53f84b974201" # for DV_NOGA_DIVISION )
Calls the I14Y public API endpoint /concepts/{conceptId} and returns
the concept metadata. Multilingual fields ('name', 'description', ...) are
returned with one entry per language (de, en, fr, it, rm).
i14y_get_concept(id = NULL, includeCodeListEntries = FALSE)i14y_get_concept(id = NULL, includeCodeListEntries = FALSE)
id |
string. The UUID of the concept. |
includeCodeListEntries |
logical. If 'TRUE', the response includes the codelist entries for code-list concepts. Default 'FALSE'. |
A list with the concept metadata. 'NULL' when offline.
i14y_get_concept( id = "08d94604-e058-62a2-aa25-53f84b974201" # DV_NOGA_DIVISION )i14y_get_concept( id = "08d94604-e058-62a2-aa25-53f84b974201" # DV_NOGA_DIVISION )
Calls the I14Y public API endpoint
/concepts/{conceptId}/exports/json.
i14y_get_concept_export(id = NULL)i14y_get_concept_export(id = NULL)
id |
string. The UUID of the concept. |
A list with the JSON export of the concept. 'NULL' when offline.
Calls the I14Y public API endpoint /dataservices/{dataServiceId}.
i14y_get_dataservice(id = NULL)i14y_get_dataservice(id = NULL)
id |
string. The UUID of the data service. |
A list with the data service metadata. 'NULL' when offline.
Calls the I14Y public API endpoint /datasets/{datasetId} and returns
the dataset metadata: publication level, registration status, distributions,
contact points, themes, etc.
i14y_get_dataset(id = NULL)i14y_get_dataset(id = NULL)
id |
string. The UUID of the dataset. |
A list with the dataset metadata. 'NULL' when offline.
i14y_get_dataset( id = "b902add5-9538-47ed-b663-f9fbfac92381" # SpiGes_Administratives )i14y_get_dataset( id = "b902add5-9538-47ed-b663-f9fbfac92381" # SpiGes_Administratives )
Calls the I14Y public API endpoint
/datasets/{datasetId}/structures/exports/{dataFormat}. The endpoint
returns a SHACL/RDF graph in one of the supported linked-data formats. Note
that many datasets do not have a published structure and will return an
empty result.
i14y_get_dataset_structure(id = NULL, format = "JsonLd")i14y_get_dataset_structure(id = NULL, format = "JsonLd")
id |
string. The UUID of the dataset. |
format |
string. The export format. One of "JsonLd" (default), "Ttl" or "Rdf". |
For 'format = "JsonLd"', the parsed JSON-LD graph as a list. For other formats, the raw response body as a character string. 'NULL' when offline.
i14y_get_dataset_structure( id = "b902add5-9538-47ed-b663-f9fbfac92381" # SpiGes_Administratives )i14y_get_dataset_structure( id = "b902add5-9538-47ed-b663-f9fbfac92381" # SpiGes_Administratives )
Calls the I14Y public API endpoint /mappingtables/{mappingTableId}.
i14y_get_mappingtable(id = NULL)i14y_get_mappingtable(id = NULL)
id |
string. The UUID of the mapping table. |
A list with the mapping table metadata. 'NULL' when offline.
Calls the I14Y public API endpoint
/mappingtables/{mappingTableId}/relations/exports/{dataFormat}.
i14y_get_mappingtable_relations(id = NULL, format = "Json")i14y_get_mappingtable_relations(id = NULL, format = "Json")
id |
string. The UUID of the mapping table. |
format |
string. One of "Json" (default), "Csv". |
For 'format = "Json"', a tibble of relations (one row per source/target/relationType triple). For 'format = "Csv"', the raw CSV response body as a character string. 'NULL' when offline.
Calls the I14Y public API endpoint
/publicservices/{publicServiceId}.
i14y_get_publicservice(id = NULL)i14y_get_publicservice(id = NULL)
id |
string. The UUID of the public service. |
A list with the public service metadata. 'NULL' when offline.
Calls the I14Y public API endpoint /catalogs.
i14y_list_catalogs(page = NULL, pageSize = NULL)i14y_list_catalogs(page = NULL, pageSize = NULL)
page |
integer. The result page to return. |
pageSize |
integer. The size of each result page. |
A tibble of catalog summaries. 'NULL' when offline.
Calls the I14Y public API endpoint /concepts.
i14y_list_concepts( conceptIdentifier = NULL, publisherIdentifier = NULL, version = NULL, publicationLevel = NULL, registrationStatus = NULL, page = NULL, pageSize = NULL )i14y_list_concepts( conceptIdentifier = NULL, publisherIdentifier = NULL, version = NULL, publicationLevel = NULL, registrationStatus = NULL, page = NULL, pageSize = NULL )
conceptIdentifier |
string. Filter by concept identifier. |
publisherIdentifier |
string. Filter by publisher identifier. |
version |
string. Filter by version. |
publicationLevel |
string. One of "Internal", "Public". |
registrationStatus |
string. A registration status value. |
page |
integer. The result page to return. |
pageSize |
integer. The size of each result page. |
A tibble of concept summaries. 'NULL' when offline.
Calls the I14Y public API endpoint /dataservices.
i14y_list_dataservices( accessRights = NULL, dataServiceIdentifier = NULL, publisherIdentifier = NULL, publicationLevel = NULL, registrationStatus = NULL, page = NULL, pageSize = NULL )i14y_list_dataservices( accessRights = NULL, dataServiceIdentifier = NULL, publisherIdentifier = NULL, publicationLevel = NULL, registrationStatus = NULL, page = NULL, pageSize = NULL )
accessRights |
string. Filter by access rights. |
dataServiceIdentifier |
string. Filter by data service identifier. |
publisherIdentifier |
string. Filter by publisher identifier. |
publicationLevel |
string. One of "Internal", "Public". |
registrationStatus |
string. A registration status value. |
page |
integer. The result page to return. |
pageSize |
integer. The size of each result page. |
A tibble of data service summaries. 'NULL' when offline.
Calls the I14Y public API endpoint /datasets.
i14y_list_datasets( accessRights = NULL, datasetIdentifier = NULL, publisherIdentifier = NULL, publicationLevel = NULL, registrationStatus = NULL, page = NULL, pageSize = NULL )i14y_list_datasets( accessRights = NULL, datasetIdentifier = NULL, publisherIdentifier = NULL, publicationLevel = NULL, registrationStatus = NULL, page = NULL, pageSize = NULL )
accessRights |
string. Filter by access rights. |
datasetIdentifier |
string. Filter by dataset identifier. |
publisherIdentifier |
string. Filter by publisher identifier. |
publicationLevel |
string. One of "Internal", "Public". |
registrationStatus |
string. A registration status value. |
page |
integer. The result page to return. |
pageSize |
integer. The size of each result page. |
A tibble of dataset summaries. 'NULL' when offline.
Calls the I14Y public API endpoint /mappingtables.
i14y_list_mappingtables( mappingTableIdentifier = NULL, publisherIdentifier = NULL, version = NULL, codeSystemUri = NULL, publicationLevel = NULL, registrationStatus = NULL, page = NULL, pageSize = NULL )i14y_list_mappingtables( mappingTableIdentifier = NULL, publisherIdentifier = NULL, version = NULL, codeSystemUri = NULL, publicationLevel = NULL, registrationStatus = NULL, page = NULL, pageSize = NULL )
mappingTableIdentifier |
string. Filter by mapping table identifier. |
publisherIdentifier |
string. Filter by publisher identifier. |
version |
string. Filter by version. |
codeSystemUri |
string. Filter by code system URI. |
publicationLevel |
string. One of "Internal", "Public". |
registrationStatus |
string. A registration status value. |
page |
integer. The result page to return. |
pageSize |
integer. The size of each result page. |
A tibble of mapping table summaries. 'NULL' when offline.
Calls the I14Y public API endpoint /publicservices.
i14y_list_publicservices( publicServiceIdentifier = NULL, publisherIdentifier = NULL, publicationLevel = NULL, registrationStatus = NULL, page = NULL, pageSize = NULL )i14y_list_publicservices( publicServiceIdentifier = NULL, publisherIdentifier = NULL, publicationLevel = NULL, registrationStatus = NULL, page = NULL, pageSize = NULL )
publicServiceIdentifier |
string. Filter by public service identifier. |
publisherIdentifier |
string. Filter by publisher identifier. |
publicationLevel |
string. One of "Internal", "Public". |
registrationStatus |
string. A registration status value. |
page |
integer. The result page to return. |
pageSize |
integer. The size of each result page. |
A tibble of public service summaries. 'NULL' when offline.
Calls the I14Y public API endpoint /search. This is the faceted search
over all resource types (datasets, data services, public services, concepts,
mapping tables) and replaces the previous private 'input-backend' host that
powered 'i14y_search_catalog()' and 'i14y_search_concept()' in earlier
releases.
i14y_search( query = NULL, language = "de", types = NULL, accessRights = NULL, businessEvents = NULL, conceptValueTypes = NULL, formats = NULL, publicationLevels = NULL, publicationLevelProposals = NULL, lifeEvents = NULL, publishers = NULL, registrationStatuses = NULL, registrationStatusProposals = NULL, structure = NULL, themes = NULL, page = NULL, pageSize = NULL )i14y_search( query = NULL, language = "de", types = NULL, accessRights = NULL, businessEvents = NULL, conceptValueTypes = NULL, formats = NULL, publicationLevels = NULL, publicationLevelProposals = NULL, lifeEvents = NULL, publishers = NULL, registrationStatuses = NULL, registrationStatusProposals = NULL, structure = NULL, themes = NULL, page = NULL, pageSize = NULL )
query |
string. The search query. |
language |
string. The language to use for the search ("de", "en", "fr", "it", "rm"). Default "de". |
types |
character vector. Filter by resource types. One or more of "Dataset", "DataService", "PublicService", "Concept", "MappingTable". |
accessRights |
character vector. Filter by access rights. |
businessEvents |
character vector. Filter by business events. |
conceptValueTypes |
character vector. Filter by concept value type. One or more of "CodeList", "Date", "Numeric", "String". |
formats |
character vector. Filter by distribution formats. |
publicationLevels |
character vector. Filter by publication level ("Internal", "Public"). |
publicationLevelProposals |
character vector. Filter by proposed publication level ("Internal", "Public"). |
lifeEvents |
character vector. Filter by life events. |
publishers |
character vector. Filter by publisher identifiers. |
registrationStatuses |
character vector. Filter by registration status. |
registrationStatusProposals |
character vector. Filter by proposed registration status. |
structure |
string. One of "WithStructure", "WithoutStructure". |
themes |
character vector. Filter by theme codes. |
page |
integer. The number of the result page to return. |
pageSize |
integer. The size of each result page. |
A tibble of search results. 'NULL' when offline.
i14y_search(query = "noga", language = "en")i14y_search(query = "noga", language = "en")
Thin wrapper around [i14y_search()] that restricts the result to the catalog resource types ("Dataset", "DataService", "PublicService").
i14y_search_catalog( query = NULL, language = "de", accessRights = NULL, formats = NULL, publishers = NULL, statuses = NULL, themes = NULL, types = NULL, page = NULL, pageSize = NULL )i14y_search_catalog( query = NULL, language = "de", accessRights = NULL, formats = NULL, publishers = NULL, statuses = NULL, themes = NULL, types = NULL, page = NULL, pageSize = NULL )
query |
string. The search query. |
language |
string. The language to use for the search. |
accessRights |
character vector. Filter by access rights. |
formats |
character vector. Filter by distribution formats. |
publishers |
character vector. Filter by publisher identifiers. |
statuses |
character vector. Filter by registration status. Forwarded to the 'registrationStatuses' parameter of [i14y_search()]. |
themes |
character vector. Filter by theme codes. |
types |
character vector. Restrict to a subset of catalog types. One or more of "Dataset", "DataService", "PublicService". Defaults to all three. |
page |
integer. The number of the result page to return. |
pageSize |
integer. The size of each result page. |
A tibble of catalog search results. 'NULL' when offline.
i14y_search_catalog(query = "noga")i14y_search_catalog(query = "noga")
Calls the I14Y public API endpoint
/concepts/{conceptId}/codelist-entries/search. This replaces the former
'i14y_search_nomenclature()': in the new I14Y data model, what used to be a
single multi-level nomenclature is now a set of separate codelist concepts
(e.g. 'NOGA_SECTION', 'NOGA_DIVISION', 'NOGA_GROUP', 'NOGA_CLASS').
i14y_search_codelist( id = NULL, query = NULL, language = "de", filters = NULL, page = NULL, pageSize = NULL )i14y_search_codelist( id = NULL, query = NULL, language = "de", filters = NULL, page = NULL, pageSize = NULL )
id |
string. The UUID of the codelist concept. |
query |
string. The search query. If 'NULL', all entries are returned (subject to 'filters', 'page' and 'pageSize'). |
language |
string. The language of the response data ("de", "fr", "en", "it", "rm"). Default "de". |
filters |
character vector. Optional filter expressions, passed through to the API as the 'filters' array parameter. |
page |
integer. The number of the result page to return. |
pageSize |
integer. The size of each result page. |
A tibble of codelist entry summaries. 'NULL' when offline.
i14y_search_codelist( id = "08d94604-e058-62a2-aa25-53f84b974201", # NOGA_DIVISION query = "agriculture", language = "fr" )i14y_search_codelist( id = "08d94604-e058-62a2-aa25-53f84b974201", # NOGA_DIVISION query = "agriculture", language = "fr" )
Thin wrapper around [i14y_search()] that restricts the result to the "Concept" resource type.
i14y_search_concept( query = NULL, language = "de", page = 1, pageSize = 1000, publishers = NULL, themes = NULL, conceptValueTypes = NULL, registrationStatuses = NULL )i14y_search_concept( query = NULL, language = "de", page = 1, pageSize = 1000, publishers = NULL, themes = NULL, conceptValueTypes = NULL, registrationStatuses = NULL )
query |
string. Search query. |
language |
string. The language of the response data. |
page |
integer. The number of the result page to return. |
pageSize |
integer. The size of each result page. |
publishers |
character vector. Filter by publisher identifiers. |
themes |
character vector. Filter by theme codes. |
conceptValueTypes |
character vector. One or more concept value types to filter by ("CodeList", "Date", "Numeric", "String"). |
registrationStatuses |
character vector. One or more registration statuses to filter by. |
A tibble of concept search results. 'NULL' when offline.
i14y_search_concept(query = "noga", language = "en")i14y_search_concept(query = "noga", language = "en")