| Title: | Search and Get Data from the I14Y Interoperability Platform of Switzerland |
|---|---|
| Description: | Search and download Swiss data and metadata from the I14Y interoperability platform of Switzerland using its public APIs <https://www.i14y.admin.ch/api/index.html>. |
| Authors: | Felix Luginbuhl [aut, cre, cph] (ORCID: <https://orcid.org/0009-0008-6625-2899>), Felix Lorenz [ctr] |
| Maintainer: | Felix Luginbuhl <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1.8 |
| Built: | 2026-05-25 11:57:40 UTC |
| Source: | https://github.com/lgnbhl/I14Y |
The function uses the I14Y Console API: <https://apiconsole.i14y.admin.ch/public/v1/index.html>.
i14y_get_codelist(id = NULL, format = "csv")i14y_get_codelist(id = NULL, format = "csv")
id |
string. The Id of the response data. |
format |
string. The format of the export ("csv" or "json"). |
a tibble
i14y_get_codelist( id = "08d94604-e058-62a2-aa25-53f84b974201" # for DV_NOGA_DIVISION )i14y_get_codelist( id = "08d94604-e058-62a2-aa25-53f84b974201" # for DV_NOGA_DIVISION )
Get Concept view entity by ID
i14y_get_concept(id = NULL, language = "de")i14y_get_concept(id = NULL, language = "de")
id |
string. The Id of the response data. |
language |
string. The language of the response data. |
a list
i14y_get_concept( id = "08d94604-e058-62a2-aa25-53f84b974201", # DV_NOGA_DIVISION language = "en" )i14y_get_concept( id = "08d94604-e058-62a2-aa25-53f84b974201", # DV_NOGA_DIVISION language = "en" )
Get all versions of an ID
i14y_get_concept_all_versions(id = NULL, language = "de")i14y_get_concept_all_versions(id = NULL, language = "de")
id |
string. The Id of the response data. |
language |
string. The language of the response data. |
a list
i14y_get_concept_all_versions( id = "08d94604-e058-62a2-aa25-53f84b974201", # DV_NOGA_DIVISION language = "de" )i14y_get_concept_all_versions( id = "08d94604-e058-62a2-aa25-53f84b974201", # DV_NOGA_DIVISION language = "de" )
Get the information of a nomenclature by identifier
i14y_get_content_information(id = NULL)i14y_get_content_information(id = NULL)
identifier |
string. The identifier of the nomenclature. |
a list
i14y_get_content_information( identifier = "HCL_CH_ISCO_19_PROF" )i14y_get_content_information( identifier = "HCL_CH_ISCO_19_PROF" )
Get the dataStructures
i14y_get_data_structure(identifier = NULL, language = "de")i14y_get_data_structure(identifier = NULL, language = "de")
identifier |
string. The identifier of the dcat dataset. |
language |
string. The language of the response data. |
a list
df <- i14y_get_data_structure( identifier = "SpiGes_Erhebung_Administratives" )df <- i14y_get_data_structure( identifier = "SpiGes_Erhebung_Administratives" )
Get dataset full metadata by ID
i14y_get_dataset_metadata(id = NULL)i14y_get_dataset_metadata(id = NULL)
id |
string. The id of the dcat dataset. |
a list
i14y_get_dataset_metadata(id = "02e34f85-14df-45b5-a38b-2f063c999481")i14y_get_dataset_metadata(id = "02e34f85-14df-45b5-a38b-2f063c999481")
Export a level of a nomenclature
i14y_get_nomenclature_level( identifier = NULL, language = "de", level = 1, format = "csv", annotations = FALSE, filters = NULL )i14y_get_nomenclature_level( identifier = NULL, language = "de", level = 1, format = "csv", annotations = FALSE, filters = NULL )
identifier |
string. The identifier of dcat dataset. |
language |
string. The language of the response data. |
level |
integer. The level to export. Default 1. |
format |
string. The format of the export (CSV or XLSX). |
annotations |
boolean. Include annotations. Default FALSE. |
filters |
object. The filters |
a tibble
Export multiple levels of a nomenclature
i14y_get_nomenclature_level_multiple( identifier = NULL, language = "de", levelFrom = NULL, levelTo = NULL, format = "csv", annotations = NULL, filters = NULL )i14y_get_nomenclature_level_multiple( identifier = NULL, language = "de", levelFrom = NULL, levelTo = NULL, format = "csv", annotations = NULL, filters = NULL )
identifier |
string. The identifier of dcat dataset. |
language |
string. The language of the response data. Default "de". |
levelFrom |
integer. The first level to include. |
levelTo |
integer. The last level to include. |
format |
string. The format of the export ("csv" or "xlsx"). Default "csv". |
annotations |
boolean. Include annotations |
filters |
object. The filters |
a tibble
i14y_get_nomenclature_level_multiple( identifier = "HCL_CH_ISCO_19_PROF", format = "csv", # read internally levelFrom = 1, levelTo = 2, language = "fr" )i14y_get_nomenclature_level_multiple( identifier = "HCL_CH_ISCO_19_PROF", format = "csv", # read internally levelFrom = 1, levelTo = 2, language = "fr" )
Search the catalog for datasets, data services and public services.
i14y_search_catalog( query = NULL, language = "de", accessRights = NULL, formats = NULL, publishers = NULL, statuses = NULL, themes = NULL, types = NULL, page = NULL, pageSize = NULL )i14y_search_catalog( query = NULL, language = "de", accessRights = NULL, formats = NULL, publishers = NULL, statuses = NULL, themes = NULL, types = NULL, page = NULL, pageSize = NULL )
query |
string. The search query |
language |
string. The language to use for the search |
accessRights |
vector of strings. Only results with one of the specified access rights (PUBLIC, NON_PUBLIC, RESTRICTED) are returned |
formats |
vector of strings. Only results with at least one distribution providing one of the specified formats are returned |
publishers |
vector of strings. Only results with one of the specified publishers are returned |
statuses |
vector of strings. Only results with one of the specified registration statuses are returned |
themes |
vector of strings. Only results corresponding to one of the specified themes are returned |
types |
vector of strings. Only results with one of the specified types (Dataset, DataService, PublicService) are returned |
page |
integer. The number of the result page to return |
pageSize |
integer. The size of each result page |
a tibble
i14y_search_catalog(query = "noga")i14y_search_catalog(query = "noga")
Search for a Concept Summary
i14y_search_concept( query = NULL, language = "de", page = 1, pageSize = 1000, publishers = NULL, themes = NULL, conceptValueTypes = NULL, registrationStatuses = NULL )i14y_search_concept( query = NULL, language = "de", page = 1, pageSize = 1000, publishers = NULL, themes = NULL, conceptValueTypes = NULL, registrationStatuses = NULL )
query |
string. Search query. |
language |
string. The language of the response data. |
page |
integer. The number of the result page to return. |
pageSize |
integer. The size of each result page. |
publishers |
vector of strings. Filter with Publishers identifiers. |
themes |
vector of strings. Filter with theme codes. |
conceptValueTypes |
character vector. One or more concept value types to filter by. |
registrationStatuses |
character vector. One or more registration statuses to filter by. |
a tibble
i14y_search_concept(query = "noga", language = "en")i14y_search_concept(query = "noga", language = "en")
Search within a nomenclature
i14y_search_nomenclature( identifier = NULL, query = NULL, language = "de", page = NULL, pageSize = NULL, filters = NULL )i14y_search_nomenclature( identifier = NULL, query = NULL, language = "de", page = NULL, pageSize = NULL, filters = NULL )
identifier |
string. The identifier of dcat dataset. |
query |
string. The search query. |
language |
string. The language of the response data. |
page |
integer. The number of the result page to return |
pageSize |
integer. The size of each result page |
filters |
object. The filters |
a list